Plot 3d surface of observations and model fit
fitPlot3d(
fit,
logScale = TRUE,
useFineGrid = TRUE,
showMesh = TRUE,
widget = FALSE
)A HarbronFit object returned by
fitModel.
Whether to use log-scale for x and y axes.
Whether to use fine grid for plotting the fitted surface (default), or calculate predictions only at the observed data points.
Whether to show 'mesh' on the plot. Note: currently doesn't
play nicely with the useFineGrid argument, so the latter is ignored.
Whether to return a "htmlwidget" object instead of plotting on a 3d device.
A 3d plot is shown or an object of class "htmlwidget" as returned by
rglwidget.