Function to run nonparametric bootstrap on the interaction index model.
It is usually called from getTauSurface.
getBootTaus(
fit,
niter = 100,
resample = c("all", "mono", "stratified"),
seed = NULL,
verbose = FALSE,
...
)A HarbronFit object returned by
fitModel.
Number of bootstrap samples to use.
Resampling method for bootstrap. Either "all" (default) for resampling from all data, "mono" for separately resampling monotherapy and combination data, or "stratified" for resampling at each dose combination separately. Note that the latter method is not meaningful if there are no replicates in the data.
Random seed to use for bootstrap
Whether to show progress information.
Further arguments passed to the fitModel calls.
A matrix of interaction index estimates based on the bootstrap samples.