Plot estimated interaction index surface slice along one of the doses
tauPlot2d(
tauSurface,
tauSurface2 = NULL,
side = "d1",
groupBy = NULL,
colorBy = groupBy,
facetBy = "auto",
continuous = FALSE,
continuous2 = FALSE,
addLine = continuous || continuous2,
funs = NULL,
funs2 = NULL,
title = NULL,
tauNames = NULL,
digits = 4,
facetOpts = NULL
)A tauSurface object returned by
getTauSurface.
An optional second tauSurface object returned by
getTauSurface. If provided, a 2d-plot comparing the two tau
surfaces is produced. Note that the estimates should have been calculated on
the same HarbronFit object.
Data column to use as x-axis: "d1", "d2", "total" or another
variable from the data in the tauSurface object.
Data column to use as grouping. Note that if comparison of two surfaces is performed, this will be ignored.
Data column to use for coloring.
Whether to facet plots by extra variables used in the tau formula ("auto") or manually provided data column(s) to facet by.
Whether continuous type of plot is requested (for
tauSurface1). This is automatically detected if used via
plot.tauSurface, but can be overwritten.
Whether continuous type of plot is requested (for
tauSurface2). This is automatically detected if used via
plot.tauSurface, but can be overwritten.
Whether to connect tau estimates for subsequent doses.
A list with functions to compute tau surface and confidence
bands (for tauSurface1). These are returned by the
getTauSurface and are automatically used when the
plot.tauSurface is called.
A list with functions to compute tau surface and confidence
bands (for tauSurface2). These are returned by the
getTauSurface and are automatically used when the
plot.tauSurface is called.
Plot title.
Tau surface names to use for the plot legend in the case of
comparison of estimates (i.e. when tauSurface2 is provided).
Number of digits used in format for the
dose labels.
Arguments passed to facet_wrap
A ggplot2 object.
The function returns a 2d plot for the interaction index (tau)
estimates as a function of one of the two doses in a checkerboard design, or
rays in a ray design. Pointwise confidence intervals are displayed as error
bars. In addition to plotting tau estimates from one tauSurface object,
the function can be used to compare two tauSurface objects.
This can be used, for example, to see the difference between Wald-type and
boostrap-based confidence intervals for tau.
Although the function can be used 'manually', typically one calls the
plot.tauSurface method, which then calls this function when
which = "2d".