Contour-plot method for "tauSurface" objects
# S3 method for tauSurface
contour(x, digits = 4, ...)A tauSurface object returned by getTauSurface.
Number of digits used in format for the
dose labels.
Further parameters, currently not used.
a ggplot2 object
The function returns a heatmap-like plot displaying the interaction index (tau) estimates and pointwise confidence intervals numerically. Blue and red colours are used to indicate areas of synergy (if confidence interval lies entirely below 1) or antagonism (if confidence interval lies entirely above 1). Note that color intensity is determined by the absolute values of the interaction indices.