Plot 3d surface of interaction index estimates
tauPlot3d(
tauSurface,
logScale = TRUE,
continuous = FALSE,
funs = NULL,
addPlane = continuous,
colorPoints = TRUE,
widget = FALSE
)A tauSurface object returned by
getTauSurface.
Whether to use log-scale for x and y axes.
Whether continuous type of plot is requested. This is
automatically detected if used via plot.tauSurface, but can be
overwritten.
A list with functions to compute tau surface and confidence
bands. These are returned by the getTauSurface and are
automatically used when the plot.tauSurface is called.
Whether to add estimated tau plane.
Whether to color points by synergy/antagonism. Blue color is used for points deemed synergistic (if the confidence interval lies entirely below 1), red for points deemed antagostic' (if the confidence interval lies entirely above 1). Other points are colored white.
Whether to return a "htmlwidget" object instead of plotting on 3d device.
A 3d plot is shown or an object of the class "htmlwidget" as returned by
rglwidget.
The function returns a 3d plot for the interaction index (tau)
estimates as a function of the doses of the two drugs. Pointwise confidence
intervals are displayed as error bars.
Although the function can be used 'manually', typically one calls the
plot.tauSurface method, which then calls this function when
which = "3d".